# Petroleum, prices, and protests
# Espen Geelmuyden Rød
# Last update: Nov 1 2023

# Sensitivity analysis
rm(list = ls())

library(lfe)
library(sensemakr)
library(tidyverse)

data <- read.csv("data.csv", na.strings = ".")

# Specification with felm for sensitivity analysis with clustered SEs

m1 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)

m1.se <- summary(m1)

m2 <- felm(price_usd_2015_growth_pct ~ poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)
m2.se <- summary(m2)

# Calculating f2 for the sensitivity analysis

partial_r2(m1.se$coefficients[5,3], df.residual(m1)) # For lnmonths_since_ged_event on protest_onset_2m
partial_f2(m1.se$coefficients[5,3], df.residual(m1)) # For lnmonths_since_ged_event on protest_onset_2m

partial_r2(m1.se$coefficients[1,3], df.residual(m1)) # For price_usd_2015_growth_pct on protest_onset_2m
partial_f2(m1.se$coefficients[1,3], df.residual(m1)) # For price_usd_2015_growth_pct on protest_onset_2m

partial_r2(m2.se$coefficients[4,3], df.residual(m2)) # For lnmonths_since_ged_event on price_usd_2015_growth_pct
partial_f2(m2.se$coefficients[4,3], df.residual(m2)) # For lnmonths_since_ged_event on price_usd_2015_growth_pct


vec.r2dz.x <- c(partial_r2(m2.se$coefficients[4,3], df.residual(m2)), partial_r2(m2.se$coefficients[4,3], df.residual(m2))*2, partial_r2(m2.se$coefficients[4,3], df.residual(m2))*3)
vec.r2yz.dx <- c(partial_r2(m1.se$coefficients[5,3], df.residual(m1)), partial_r2(m1.se$coefficients[5,3], df.residual(m1))*2, partial_r2(m1.se$coefficients[5,3], df.residual(m1))*3)

analysis.sensitivity.local <- sensemakr(m1.se$coefficients[1,1], m1.se$coefficients[1,2], df.residual(m1), 
                                        treatment = "price_usd_2015_growth_pct", 
                                        r2dz.x = vec.r2dz.x, r2yz.dx = vec.r2yz.dx,
                                        bound_label = c("ln(T s GED)","ln(T s GED) X2","ln(T s GED) X3"))

# long description of results
summary(analysis.sensitivity.local)

# plot bias contour of point estimate
plot(analysis.sensitivity.local) #, lim.x=1, lim.y=0.1)

pdf("sensitivity_estimate.pdf", height=4, width=4)
par(mar=c(4.5,4.5,1,1))
plot(analysis.sensitivity.local, lim=0.4, lim.y=0.2)
dev.off()

# plot bias contour of t-value
plot(analysis.sensitivity.local, sensitivity.of = "t-value") #, lim=0.015, lim.y=0.015)

pdf("sensitivity_tvalue.pdf", height=4, width=4)
par(mar=c(4.5,4.5,1,1))
plot(analysis.sensitivity.local, sensitivity.of = "t-value", lim=0.4, lim.y=0.2)
dev.off()

# plot extreme scenario
plot(analysis.sensitivity.local, type = "extreme")

# latex code for sensitivity table
ovb_minimal_reporting(analysis.sensitivity.local)

# data.frame with sensitivity statistics
analysis.sensitivity.local$sensitivity_stats

#  data.frame with bounds on the strengh of confounders
analysis.sensitivity.local$bounds

